
/******************************************************************************
* MODULE     : tm_config.gen.h
* DESCRIPTION: Configuration routines for TeXmacs server
* COPYRIGHT  : (C) 1999  Joris van der Hoeven
*******************************************************************************
* This software falls under the GNU general public license and comes WITHOUT
* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
* If you don't have this file, write to the Free Software Foundation, Inc.,
* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
******************************************************************************/

#ifndef TM_CONFIG_H
#define TM_CONFIG_H
#include "server.hh"
#include "hashmap.hh"

class tm_config_rep: virtual public server_rep {
protected:
  string in_lan;                             // current input language
  string out_lan;                            // current output language
  string var_suffix;                         // space + the variant key
  string unvar_suffix;                       // space + the unvariant key
  hashmap<string,tree>   latex_cmds;         // latex (or user) commands
  hashmap<string,string> latex_help;         // help messages for commands
  hashmap<string,tree>   keymap;             // the current key map
  hashmap<tree,tree>     invmap;             // the inverse key map
  hashmap<string,tree>   pre_kbd_wildcards;  // wildcards applied to defns
  hashmap<string,tree>   post_kbd_wildcards; // wildcards applied at lookup
  hashmap<string,string> shorthands;         // current shorthands
  hashmap<string,string> help_message;       // help messages for shortcuts

public:
  tm_config_rep ();
  ~tm_config_rep ();

  /* Set and get input and output languages */
  void   set_input_language (string s);
  void   set_output_language (string s);
  string get_input_language ();
  string get_output_language ();

  /* Font setup */
  void set_font_rules (scheme_tree rules);

  /* Keyboard behaviour */
  void set_latex_commands (scheme_tree cmds);
  void set_latex_symbols (scheme_tree syms);
  bool get_latex_command (string which, string& help, scheme_tree& p);

  void insert_kbd_wildcard (string key, string im, bool post, bool l, bool r);
  void insert_key_binding (string pred, string key, scheme_tree im);
  void delete_key_binding (string key);
  void delete_key_binding (string pred, string key);
  void delete_inv_binding (tree what, scheme_tree im);
  scheme_tree find_key_binding (string key);
  scheme_tree find_key_binding (string pred, string key);
  string      find_inv_binding (scheme_tree im);
  void determine_sub_key_bindings (string pred, string s);
  void set_keymap (scheme_tree preds, scheme_tree cmds);
  void remove_keymap (scheme_tree preds, scheme_tree cmds);
  void set_variant_keys (string var, string unvar);
  void variant_simplification (string& which);
  string rewrite_keycomb (string s);
  void get_keycomb (string& which, int& status,
		    scheme_tree& keym, string& shorth, string& help);
};


#endif // defined TM_CONFIG_H
